**Example 1: 修改计费类型**



Input: 

```
tccli cdn UpdatePayType --cli-unfold-argument  \
    --Area mainland \
    --PayType flux
```

Output: 
```
{
    "Response": {
        "RequestId": "1732a0dd-48d8-4ff1-8dcb-7f04ca139825"
    }
}
```

